<?php
 /*
	Plugin Name: WP Snowfall
	Plugin URI: http://zourbuth.com/archives/765/wp-snowfall-creating-wordpress-snow-effects-with-jquery-snowfall/
	Description: Display snowfall effect in your site body. Just activate this, and the snow will come to your site. Merry Christmas & Happy New Year!
	Version: 1.2.1
	Author: zourbuth
	Author URI: http://zourbuth.com
	License: Under GPL2

	Copyright 2011 zourbuth (email : zourbuth@gmail.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/**
 * Exit if accessed directly
 * @since 1.2.1
 */
if ( ! defined( 'ABSPATH' ) )
	exit;


/**
 * Set constant path to the members plugin directory
 * @since 1.0.0
 */
define( 'WP_SNOWFALL_DIR', plugin_dir_path( __FILE__ ) );
define( 'WP_SNOWFALL_URL', plugin_dir_url( __FILE__ ) );
define( 'WP_SNOWFALL_VERSION', '1.2.1' );


/**
 * Launch the plugin
 * @since 1.0.0
 */
add_action( 'plugins_loaded', 'wp_snowfall_plugins_loaded' );


/**
 * Initializes the plugin and it's features
 * @since 1.0.0
 */
function wp_snowfall_plugins_loaded() {
	// Loads the snowfall.
	add_action( 'wp_head', 'wp_snowfall_source', 1 );
	add_action( 'wp_head', 'wp_snowfall_bg', 10 );
	add_action( 'wp_footer', 'wp_snowfall_effect' );
}


/**
 * Enqueue the scripts and styles to 
 * the site header using wp_head
 * @since 1.0.0
 */
function wp_snowfall_source() {
	wp_enqueue_script( 'snowfall', WP_SNOWFALL_URL . 'js/snowfall.min.jquery.js', array( 'jquery'), WP_SNOWFALL_VERSION );
}


/**
 * Enqueue the scripts and styles to 
 * the site header using wp_head
 * @since 1.2.1
 */
function wp_snowfall_bg() {
	if( get_option('snowfall_bg_color') ) echo '<style type="text/css">body { background-color: '. get_option('snowfall_bg_color') . ';}</style>' . "\n";	
}


/**
 * Enqueue the scripts and styles to 
 * the site footer using wp_footer
 * @since 1.0.0
 */
function wp_snowfall_effect() { ?>
	<script type="text/javascript">
		jQuery(document).ready(function(){
			jQuery(document).snowfall({
				flakeCount : <?php if( get_option('snowfall_flake_count') ) echo get_option('snowfall_flake_count'); else echo 300; ?>,
				flakeColor : "#ffffff",
				flakeIndex: <?php if( get_option('snowfall_flake_index') ) echo get_option('snowfall_flake_index'); else echo 999999; ?>,
				minSize : <?php if( get_option('snowfall_minimum_size') ) echo get_option('snowfall_minimum_size'); else echo 1; ?>,
				maxSize : <?php if( get_option('snowfall_maximum_size') ) echo get_option('snowfall_maximum_size'); else echo 3; ?>,
				minSpeed : <?php if( get_option('snowfall_minimum_speed') ) echo get_option('snowfall_minimum_speed'); else echo 2; ?>,
				maxSpeed : <?php if( get_option('snowfall_maximum_speed') ) echo get_option('snowfall_maximum_speed'); else echo 3; ?>,
				round : true,
				shadow : false,
			});
		});	
	</script><?php
}


/*
* Creating Additional Settins Menu
* add_options_page( $page_title, $menu_title, $capability, $menu_slug, $function);
* Since 1.0
*/
add_action( 'admin_menu', 'snowfall_menu' );


/*
* The enqueue function, registers and enqueue the.
* Since 1.0
*/
function snowfall_admin_css() {
    wp_enqueue_style( 'wp-color-picker' );        
	wp_enqueue_script( 'wp-color-picker' );  
}

// Create options page and print the style and script.
function snowfall_menu() {
	$snowfall_menu = add_options_page('Snowfall Options', 'Snowfall', 'manage_options', 'wp-snowfall', 'wp_snowfall_options');
	add_action('admin_print_styles-' . $snowfall_menu, 'snowfall_admin_css');
}

// Create the options page content.
function wp_snowfall_options() {
	if ( !current_user_can( 'manage_options' ) )  {
		wp_die( __('You do not have sufficient permissions to access this page.', 'wp-snowfall') );
	} ?>
		<div class="wrap">
			<?php screen_icon(); ?><h2>Snowfall Settings</h2>

			<form method="post" action="options.php">
				<input type="hidden" name="action" value="update" />
				<input type="hidden" name="page_options" value="snowfall_flake_count, snowfall_bg_color, snowfall_flake_index, snowfall_minimum_size, snowfall_maximum_size, snowfall_minimum_speed, snowfall_maximum_speed" />
				
				<?php wp_nonce_field('update-options'); ?>
				
				<?php
					$args = array(
						'flakeCount' 	=> get_option('snowfall_flake_count') ? (int) get_option('snowfall_flake_count') : 300,
						'bgColor' 		=> get_option('snowfall_bg_color') ? get_option('snowfall_bg_color') : '',
						'flakeIndex'	=> get_option('snowfall_flake_index') ? (int) get_option('snowfall_flake_index') : 999999,
						'minSize' 		=> get_option('snowfall_minimum_size') ? (int) get_option('snowfall_minimum_size') : 1,
						'maxSize' 		=> get_option('snowfall_maximum_size') ? (int) get_option('snowfall_maximum_size') : 3,
						'minSpeed' 		=> get_option('snowfall_minimum_speed') ? (int) get_option('snowfall_minimum_speed') : 2,
						'maxSpeed' 		=> get_option('snowfall_maximum_size') ? (int) get_option('snowfall_maximum_size') : 3,
						'round' 		=> false,
						'shadow' 		=> false,
					);				
					extract( $args, EXTR_SKIP );
				?>

				<table class="form-table">
					<tbody><tr>
						<th><label>Flake Count</label></th>
						<td><input type="number" value="<?php echo $flakeCount; ?>" name="snowfall_flake_count" /></td>
					</tr>
					<tr>
						<th><label>Background Color</label></th>
						<td><input type="text" value="<?php echo $bgColor; ?>" id="snowfall_bg_color" name="snowfall_bg_color" /></td>
					</tr>
					<tr>
						<th><label>Flake Index</label></th>
						<td><input type="number" value="<?php echo $flakeIndex; ?>" name="snowfall_flake_index" /></td>
					</tr>
					<tr>
						<th><label>Minimum Size</label></th>
						<td><input type="number" value="<?php echo $minSize; ?>" name="snowfall_minimum_size" /></td>
					</tr>
					<tr>
						<th><label>Maximum Size</label></th>
						<td><input type="number" value="<?php echo $maxSize; ?>" name="snowfall_maximum_size" /></td>
					</tr>
					<tr>
						<th><label>Minimum Speed</label></th>
						<td><input type="number" value="<?php echo $minSpeed; ?>" name="snowfall_minimum_speed" /></td>
					</tr>
					<tr>
						<th><label>Maximum Speed</label></th>
						<td><input type="number" value="<?php echo $maxSpeed; ?>" name="snowfall_maximum_speed" /></td>
					</tr>
					</tbody>
				</table>
				<p class="submit"><input type="submit" value="Save Changes" class="button-primary" id="submit" name="submit" /></p>  
			</form>
		</div>
		<script type='text/javascript'>
			jQuery(document).ready(function($) {
				$('#snowfall_bg_color').wpColorPicker();
			});
		</script>		
	<?php
}
?>